<?php
/**
 * ADB functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 */

#region ---IMPORT---

function theme_adb_register_styles() {
	$version = wp_get_theme()->get( 'Version' ); 
	wp_enqueue_style( 'bootstrap', get_theme_file_uri('./bootstrap/css/bootstrap.css'), array(), '5.0.2');
	wp_enqueue_style('adb_theme_style', get_theme_file_uri("./style.css"), array('bootstrap'), $version, "all");
}

function theme_adb_register_fullcalendar_styles() {
	wp_enqueue_style( 'fullcalendar', get_theme_file_uri('./fullcalendar/main.min.css'), array(), '5.11.0');
}

function theme_adb_register_fullcalendar_scripts() {
	wp_enqueue_script('fullcalendar', get_theme_file_uri('./fullcalendar/main.min.js'), array(), "5.11.0", true );
	wp_enqueue_script('fullcalendar_fr', get_theme_file_uri('./fullcalendar/locales/fr.js'), array(), "5.11.0", true );
}

function theme_adb_register_bootstrap_scripts() {
	wp_enqueue_script('bootstrap', get_theme_file_uri('./bootstrap/js/bootstrap.js'), array('jquery'), "5.0.2", true );
}

$path = parse_url($_SERVER['REQUEST_URI'])['path']; // Current path
$annonces_saison_path = parse_url(get_permalink(get_option("annonces_saison_page")))['path'];
$annonce_saison_path = parse_url(get_permalink(get_option("annonce_saison_page")))['path'];
$annonces_path = parse_url(get_permalink(get_option("annonces_page")))['path'];
$annonce_path = parse_url(get_permalink(get_option("annonce_page")))['path'];

$bootstrap_script = [$annonces_saison_path, $annonce_saison_path, $annonces_path, $annonce_path]; // Load bootstrap script on this pages
$fullcalendar = [$annonce_saison_path]; // Load fullcalendar on this pages

add_action("wp_enqueue_scripts", "theme_adb_register_styles");

if (in_array($path, $bootstrap_script)) {
	add_action("wp_enqueue_scripts", "theme_adb_register_bootstrap_scripts");
}

if (in_array($path, $fullcalendar)) {
	add_action("wp_enqueue_scripts", "theme_adb_register_fullcalendar_styles");
	add_action("wp_enqueue_scripts", "theme_adb_register_fullcalendar_scripts");
}

#endregion

if ( ! function_exists( 'adb_support' ) ) :
	function adb_support() {

		// Add support for block styles.
		add_theme_support( 'wp-block-styles' );

		// Enqueue editor styles.
		add_editor_style( 'style.css' );

	}
endif;

add_action( 'after_setup_theme', 'adb_support' );

if ( ! function_exists( 'adb_styles' ) ) :

	function adb_styles() {
		// Register theme stylesheet.
		$theme_version = wp_get_theme()->get( 'Version' );

		$version_string = is_string( $theme_version ) ? $theme_version : false;
		wp_register_style(
			'adb-style',
			get_template_directory_uri() . '/style.css',
			array(),
			$version_string
		);

		// Enqueue theme stylesheet.
		wp_enqueue_style( 'adb-style' );

	}

endif;

add_action( 'wp_enqueue_scripts', 'adb_styles' );

function wpm_hide_errors() {
	// Custom error
	return "L'identifiant ou le mot de passe est incorrect";
}

add_filter('login_errors', 'wpm_hide_errors');

// Add block patterns
require get_template_directory() . '/inc/block-patterns.php';
